Graph Analysis
==============

Call graph extraction, spectral partitioning, Kameda reachability, and
hierarchical decomposition.

.. automodule:: curate_ipsum.graph
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.models
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.extractor
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.ast_extractor
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.asr_extractor
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.dependency_extractor
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.spectral
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.partitioner
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.planarity
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.kameda
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.graph.hierarchy
   :members:
   :show-inheritance:
